from hdsr_wis_config_reader.constants.location_sets import hoofd
from hdsr_wis_config_reader.constants.location_sets import msw
from hdsr_wis_config_reader.constants.location_sets import ow
from hdsr_wis_config_reader.constants.location_sets import ps
from hdsr_wis_config_reader.constants.location_sets import sub
from hdsr_wis_config_reader.constants.location_sets.collection import LocationSetCollection


# silence flake8 errors
hoofd = hoofd
msw = msw
ow = ow
ps = ps
sub = sub
LocationSetCollection = LocationSetCollection
